@@ -16,12 +16,12 @@ from yarl import URL
 
 from simplipy.const import DEFAULT_USER_AGENT, LOGGER
 from simplipy.errors import (
-    EndpointUnavailableError,
     InvalidCredentialsError,
     RequestError,
     SimplipyError,
     Verify2FAError,
     Verify2FAPending,
+    raise_on_data_error,
 )
 from simplipy.system.v2 import SystemV2
 from simplipy.system.v3 import SystemV3
@@ -213,7 +213,7 @@ class API:  # pylint: disable=too-many-instance-attributes
         """
         api = cls(session=session, request_retries=request_retries)
         api.refresh_token = refresh_token
-        await api._async_refresh_access_token()
+        await api.async_refresh_access_token()
         await api._async_post_init()
         return api
 
@@ -267,7 +267,7 @@ class API:  # pylint: disable=too-many-instance-attributes
 
         LOGGER.debug("Error during request attempt: %s", err)
 
-        if err.status in (401, 403):
+        if err.status == 401:
             assert self._token_last_refreshed
 
             # Calculate the window between now and the last time the token was
@@ -284,7 +284,7 @@ class API:  # pylint: disable=too-many-instance-attributes
                     return
 
                 LOGGER.info("401 detected; attempting refresh token")
-                await self._async_refresh_access_token()
+                await self.async_refresh_access_token()
 
     async def _async_post_init(self) -> None:
         """Perform some post-init actions."""
@@ -293,35 +293,6 @@ class API:  # pylint: disable=too-many-instance-attributes
         self.user_id = auth_check_resp["userId"]
         self.websocket = WebsocketClient(self)
 
-    async def _async_refresh_access_token(self) -> None:
-        """Update access/refresh tokens from a refresh token."""
-        try:
-            token_resp = await self.session.request(
-                "post",
-                f"{AUTH_URL_BASE}/oauth/token",
-                json={
-                    "grant_type": "refresh_token",
-                    "client_id": DEFAULT_CLIENT_ID,
-                    "refresh_token": self.refresh_token,
-                },
-            )
-            token_resp.raise_for_status()
-        except ClientResponseError as err:
-            if err.status in (401, 403):
-                raise InvalidCredentialsError("Invalid refresh token") from err
-            raise RequestError(
-                f"Request error while attempting to refresh access token: {err}"
-            ) from err
-        except Exception as err:  # pylint: disable-broad-except
-            raise SimplipyError(
-                f"Error while attempting to refresh access token: {err}"
-            ) from err
-
-        await self._async_save_token_data_from_response(token_resp)
-
-        for callback in self._refresh_token_callbacks:
-            execute_callback(callback, self.refresh_token)
-
     async def _async_api_request(
         self, method: str, endpoint: str, url_base: str = API_URL_BASE, **kwargs: Any
     ) -> dict[str, Any]:
@@ -341,15 +312,11 @@ class API:  # pylint: disable=too-many-instance-attributes
                 data = await resp.json(content_type=None)
             except JSONDecodeError:
                 message = await resp.text()
-                data = {"error": message}
+                data = {"type": "DataParsingError", "message": message}
 
             LOGGER.debug("Data received from /%s: %s", endpoint, data)
 
-            if data and data.get("type") == "NoRemoteManagement":
-                raise EndpointUnavailableError(
-                    f"Endpoint unavailable in plan: {endpoint}"
-                ) from None
-
+            raise_on_data_error(data)
             resp.raise_for_status()
 
         return data
@@ -370,6 +337,24 @@ class API:  # pylint: disable=too-many-instance-attributes
         err = err_info[1].with_traceback(err_info[2])  # type: ignore
         raise RequestError(err) from err
 
+    @staticmethod
+    def is_fatal_error(err: ClientResponseError) -> bool:
+        """Determine whether a ClientResponseError is fatal and shouldn't be retried.
+
+        In general, we retry anything outside of HTTP 4xx codes (client errors) with a
+        few exceptions:
+
+        1. 401: We catch this, refresh the access token, and retry the original request.
+        2. 409: SimpliSafe base stations regular synchronize themselves with the API,
+                which is where this error can occur; we can't control when/how that
+                happens (e.g., we might query the API in the middle of a base station
+                update), so it should be viewed as retryable.
+        """
+        assert isinstance(err.status, int)
+        if err.status in (401, 409):
+            return False
+        return 400 <= err.status < 500
+
     def _wrap_request_method(self, request_retries: int) -> Callable:
         """Wrap the request method in backoff/retry logic."""
         return cast(
@@ -377,6 +362,7 @@ class API:  # pylint: disable=too-many-instance-attributes
             backoff.on_exception(
                 backoff.expo,
                 ClientResponseError,
+                giveup=self.is_fatal_error,
                 jitter=backoff.random_jitter,
                 logger=LOGGER,
                 max_tries=request_retries,
@@ -447,6 +433,38 @@ class API:  # pylint: disable=too-many-instance-attributes
 
         return systems
 
+    async def async_refresh_access_token(self) -> None:
+        """Initiate a refresh of the access/refresh tokens.
+
+        Note that this will execute any callbacks added via add_refresh_token_callback.
+        """
+        try:
+            token_resp = await self.session.request(
+                "post",
+                f"{AUTH_URL_BASE}/oauth/token",
+                json={
+                    "grant_type": "refresh_token",
+                    "client_id": DEFAULT_CLIENT_ID,
+                    "refresh_token": self.refresh_token,
+                },
+            )
+            token_resp.raise_for_status()
+        except ClientResponseError as err:
+            if err.status in (401, 403):
+                raise InvalidCredentialsError("Invalid refresh token") from err
+            raise RequestError(
+                f"Request error while attempting to refresh access token: {err}"
+            ) from err
+        except Exception as err:  # pylint: disable-broad-except
+            raise SimplipyError(
+                f"Error while attempting to refresh access token: {err}"
+            ) from err
+
+        await self._async_save_token_data_from_response(token_resp)
+
+        for callback in self._refresh_token_callbacks:
+            execute_callback(callback, self.refresh_token)
+
     async def async_update_subscription_data(self) -> None:
         """Get the latest subscription data."""
         subscription_resp = await self.async_request(
